(function() {
    "use strict";

    angular.module("weChatApp", ["ngRoute", "ngAnimate"])
        .config(["$routeProvider", AppConfig])
    ;

    function AppConfig($routeProvider) {
        $routeProvider
            .when("/", {
                templateUrl: "views/wechat-rep-dashboard.html",
                controller: "dashboardCtrl",
                controllerAs: "dash",
                resolve: {
                    _currentUser: ["$q", "UserService", function($q, userService) {
                        var deferred = $q.defer();

                        userService.getCurrentUser().then(function(currentUser) {
                            deferred.resolve(currentUser);
                        });

                        return deferred.promise;
                    }],
                    _veevaMessages: ["$q", "UserService", "TranslationService", function($q, userService, translationService) {
                        var deferred = $q.defer();

                        userService.getCurrentUser().then(function(currentUser) {
                            translationService.getVeevaMessages(currentUser.LanguageLocaleKey, "en_US").then(function(resp) {
                                deferred.resolve(resp);
                            });
                        });

                        return deferred.promise;
                    }],
                    _unreachableObjects: ["$q", "Queries", "PermissionService", function($q, queries, permissionService) {
                        var deferred = $q.defer();

                        permissionService.checkObjectAndFieldFLS(queries).then(function(unreachableObjects) {
                            /**
                             * The unreachableObjects can be used to check missing FLS on object, fields. Its structure is
                             * { object_api_name_1: [], object_api_name_2: [] }
                             *
                             * For object missing field(s) access, the unreachableObjects structure will be
                             * { object_api_name_1: [field1], object_api_name_2: [field1, field2] }
                             */
                            deferred.resolve(unreachableObjects);
                        });

                        return deferred.promise;
                    }]
                }
            })
        ;
    }
}());